==> mahara_1.0.4.orig.tar.gz: mahara-1.0.4/htdocs/lang/en.utf8/install.php <==
<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage lang
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
 *
 */

defined('INTERNAL') || die();

$string['aboutdefaultcontent'] = '<h2>About Mahara</h2>

<p>Established in 2006, Mahara is the result of a collaborative venture funded by New Zealand\'s Tertiary Education Commission\'s e-learning Collaborative Development Fund (eCDF), involving Massey University, Auckland University of Technology, The Open Polytechnic of New Zealand and Victoria University of Wellington.</p>

<p>Mahara is a fully featured electronic portfolio, weblog, resume builder and social networking system, connecting users and creating online communities. Mahara is designed to provide users with the tools to create a personal and professional learning and development environment.</p>

<p>Meaning `think\' or `thought\' in Te Reo Maori, the name reflects the project collaborator\'s dedication to creating a user-centred life long learning and development application as well as the belief that technology solutions cannot be developed outside the considerations of pedagogy and policy.</p>

<p>Mahara is provided freely as Open Source software (under the GNU General Public License). In brief, this means that you are allowed to copy, use and modify Mahara provided you agree to:</p>

<ul>
    <li>provide the source code to others; </li>
    <li>not modify or remove the original license and copyrights, and</li>
    <li>apply this same license to any derivative work.</li>
</ul>

<p>Please feel free to <a href="contact.php">Contact Us</a> if you have any questions regarding Mahara.</p>

<p><a href="http://mahara.org">http://mahara.org</a></p>';
$string['homedefaultcontent'] = '<h2>Welcome to Mahara</h2>

<p>Mahara is a fully featured electronic portfolio, weblog, resume builder and social networking system, connecting users and creating online communities.  Mahara provides you with the tools to set up a personal learning and development environment.</p>

<p>For more information you can read <a href="about.php">About</a> Mahara or alternatively please feel free to <a href="contact.php">Contact Us</a>.</p>';
$string['loggedouthomedefaultcontent'] = '<h2>Welcome to Mahara</h2>

<p>Mahara is a fully featured electronic portfolio, weblog, resume builder and social networking system, connecting users and creating online communities.  Mahara provides you with the tools to set up a personal learning and development environment.</p>

<p>For more information you can read <a href="about.php">About</a> Mahara or alternatively please feel free to <a href="contact.php">Contact Us</a>.</p>';
$string['privacydefaultcontent'] = '<h2>Privacy Statement</h2>
    
<h3>Introduction</h3>

<p>We are committed to protecting your privacy and providing users with a safe and functional personal learning and development environment. This Statement of Privacy applies to the Mahara site and governs data collection and usage.</p>

<h3>Collection of personal information</h3>

<p>By registering on Mahara you will be required to provide us with a certain amount of personal information.  We will not disclose any of your personal information to any other person or organisation without your written consent unless authorised or required by law.</p>

<h3>Cookies</h3>

<p>In order to use Mahara you must have cookies enabled within your browser.  Please note that no personal information is stored within the cookies used in Mahara.</p>

<p>A cookie is a data file that is placed on your computer by a webpage server. Cookies are not programs, spyware or viruses and are unable to perform any operation by themselves.</p>

<h3>How we use your personal information</h3>

<p>We will only use your personal information for the purpose for which you provided it to us.</p>

<p>As Mahara users you are able to determine what personal information you make available to others.  By default, unless assigned Administrator, Course Creator or Tutor access rights,  a user may only view your Preferred Name.  This includes listings within a Notification report or Visitor Log.</p>

<p>We may also collect system usage for statistical purposes however this data will not identify any individual.</p>

<h3>Storage and security of your personal information</h3>

<p>We will take all reasonable steps to ensure that any personal information we hold is not subject to loss or misuse or unauthorised access, disclosure or alteration.</p>

<p>In order to help protect your personal information, please do not disclose your Username or Password to person other than the Site Administrator.</p>

<h3>Changes to this privacy statement</h3>

<p>We may occasionally make adjustments to our privacy statement to reflect changes to the system and in response to customer feedback. As such we suggest you check the Privacy Statement each time you visit this site.</p>

<h3>Contact</h3>

<p>If you have any questions regarding this Statement or believe we have not adhered to the above criteria, please <a href="contact.php">Contact Us</a> and we will use all reasonable efforts to remedy the issue.</p>';
$string['termsandconditionsdefaultcontent'] = '<h2>Terms and Conditions</h2>

<p>By using [Mahara] you are agreeing to the Terms and Conditions given below.</p>

<h3>Our obligations</h3>

<p>The [Mahara] Site Administrators will undertake all reasonable steps to provide all users with a safe , secure and operational electronic portfolio system.  If at any time you feel your rights as a user have not been upheld or you have any questions regarding the below, please <a href="contact.php">Contact Us</a> immediately.</p>

<p>[Mahara] will occasionally be unavailable for short periods of time as we release new system features.  We will endeavour to provide at least 3 working days notice of any scheduled outage.</p>

<p>You are encouraged to report objectionable material or inappropriate behaviour to the <a href="contact.php">Site Administrator</a> immediately.  We will ensure the matter is investigated in a timely manner.</p>

<p>Site Administrators may access your portfolio and its contents at anytime, however they will avoid doing so unless specifically required to support your use of [Mahara] or as per these Terms and Conditions.</p>

<h3>Your obligations</h3>

<p> The <a href="privacy.php">Privacy Statement</a> should be considered an extension of these Terms and Conditions and be read by all users.</p>

<p>Your [Mahara] account will expire after a given period of time or after given period of inactivity, as set by the Site Administrator. You will receive an email reminder shortly before your account is due to expire and we suggest you save your portfolio to your personal computer at this time, so that you may reuse it in the future.</p>

<p>All files and content you upload to [Mahara] are subject to New Zealand Copyright legislation.  You are responsible for ensuring you have appropriate permission to reproduce and publish any work that is not your own.  Incidents of plagiarism will be dealt with in accordance to your educational institution\'s policy.</p>

<p>You must not use your portfolio to store or display offensive material.  If the Site Administrator receives report of any objectionable material within your portfolio, your account will be suspended and your access to [Mahara] frozen pending an investigation in accordance to the Student Conduct Policy or equivalent of your educational institution.  Where no Conduct Policy exists the matter will be referred to an appropriate staff member of your institution or organisation.</p>

<p>If the Site Administrator receives report of any inappropriate behaviour on your part, where it relates to [Mahara], your account will be suspended and your access to [Mahara] frozen pending an investigation in accordance to the Student Conduct Policy or equivalent of your educational institution.  Where no Conduct Policy exists the matter will be referred to an appropriate staff member of your institution or organisation.</p>

<p>Inappropriate behaviour includes misuse of the objectionable material reporting system, intentionally attempting to load files with virus content, placing objectionable or excessive feedback or comments on any other users portfolio and any other behaviour deemed to be nuisance or offensive by the Site Administrator.</p>

<p>Any unsolicited contact you receive as a result of personal information you have publicly released via your portfolio is your responsibility, however any misconduct in behaviour from users of the system should be reported to the <a href="contact.php">Site Administrator</a> immediately.  We may occasionally make minor adjustments to our Terms and Condition to reflect changes to the system and in response to user feedback.  As such we suggest you check the Terms and Conditions each time you visit this site.  We will however notify users of any major changes to the Terms and Conditions via the [Mahara] homepage.</p>';

$string['uploadcopyrightdefaultcontent'] = 'Yes: The file I am attempting to upload is my own or I have express permission to reproduce and/or distribute this item.  My use of this file does not breach any of my local Copyright legislation. This file also adheres to the Terms and Conditions outlined on this site.';

?>

==> mahara_1.2.4.orig.tar.gz: mahara-1.2.4/htdocs/lang/en.utf8/install.php <==
<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
 *                         http://wiki.mahara.org/Contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage lang
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
 *
 */

defined('INTERNAL') || die();

$string['aboutdefaultcontent'] = '<h1>About Mahara</h1>

<p>Established in 2006, Mahara is the result of a collaborative venture funded by New Zealand\'s Tertiary Education Commission\'s e-learning Collaborative Development Fund (eCDF), involving Massey University, Auckland University of Technology, The Open Polytechnic of New Zealand and Victoria University of Wellington.</p>

<p>Mahara is a fully featured electronic portfolio, weblog, resume builder and social networking system, connecting users and creating online communities. Mahara is designed to provide users with the tools to create a personal and professional learning and development environment.</p>

<p>Meaning `think\' or `thought\' in Te Reo Maori, the name reflects the project collaborator\'s dedication to creating a user-centred life long learning and development application as well as the belief that technology solutions cannot be developed outside the considerations of pedagogy and policy.</p>

<p>Mahara is provided freely as Open Source software (under the GNU General Public License). In brief, this means that you are allowed to copy, use and modify Mahara provided you agree to:</p>

<ul>
    <li>provide the source code to others; </li>
    <li>not modify or remove the original license and copyrights, and</li>
    <li>apply this same license to any derivative work.</li>
</ul>

<p>Please feel free to <a href="contact.php">Contact Us</a> if you have any questions regarding Mahara.</p>

<p><a href="http://mahara.org">http://mahara.org</a></p>';
$string['homedefaultcontent'] = '<h1>Welcome to Mahara</h1>

<p>Mahara is a fully featured electronic portfolio, weblog, resume builder and social networking system, connecting users and creating online communities.  Mahara provides you with the tools to set up a personal learning and development environment.</p>

<p>For more information you can read <a href="about.php">About</a> Mahara or alternatively please feel free to <a href="contact.php">Contact Us</a>.</p>';
$string['loggedouthomedefaultcontent'] = '<h1>Welcome to Mahara</h1>

<p>Mahara is a fully featured electronic portfolio, weblog, resume builder and social networking system, connecting users and creating online communities.  Mahara provides you with the tools to set up a personal learning and development environment.</p>

<p>For more information you can read <a href="about.php">About</a> Mahara or alternatively please feel free to <a href="contact.php">Contact Us</a>.</p>';
$string['privacydefaultcontent'] = '<h1>Privacy Statement</h1>
    
<h2>Introduction</h2>

<p>We are committed to protecting your privacy and providing users with a safe and functional personal learning and development environment. This Statement of Privacy applies to the Mahara site and governs data collection and usage.</p>

<h2>Collection of personal information</h2>

<p>By registering on Mahara you will be required to provide us with a certain amount of personal information.  We will not disclose any of your personal information to any other person or organisation without your written consent unless authorised or required by law.</p>

<h2>Cookies</h2>

<p>In order to use Mahara you must have cookies enabled within your browser.  Please note that no personal information is stored within the cookies used in Mahara.</p>

<p>A cookie is a data file that is placed on your computer by a webpage server. Cookies are not programs, spyware or viruses and are unable to perform any operation by themselves.</p>

<h2>How we use your personal information</h2>

<p>We will only use your personal information for the purpose for which you provided it to us.</p>

<p>As Mahara users you are able to determine what personal information you make available to others.  By default, unless assigned Administrator, Course Creator or Tutor access rights,  a user may only view your Display Name.  This includes listings within a Notification report or Visitor Log.</p>

<p>We may also collect system usage for statistical purposes however this data will not identify any individual.</p>

<h2>Storage and security of your personal information</h2>

<p>We will take all reasonable steps to ensure that any personal information we hold is not subject to loss or misuse or unauthorised access, disclosure or alteration.</p>

<p>In order to help protect your personal information, please do not disclose your Username or Password to person other than the Site Administrator.</p>

<h2>Changes to this privacy statement</h2>

<p>We may occasionally make adjustments to our privacy statement to reflect changes to the system and in response to customer feedback. As such we suggest you check the Privacy Statement each time you visit this site.</p>

<h2>Contact</h2>

<p>If you have any questions regarding this Statement or believe we have not adhered to the above criteria, please <a href="contact.php">Contact Us</a> and we will use all reasonable efforts to remedy the issue.</p>';
$string['termsandconditionsdefaultcontent'] = '<h1>Terms and Conditions</h1>

<p>By using [Mahara] you are agreeing to the Terms and Conditions given below.</p>

<h2>Our obligations</h2>

<p>The [Mahara] Site Administrators will undertake all reasonable steps to provide all users with a safe , secure and operational electronic portfolio system.  If at any time you feel your rights as a user have not been upheld or you have any questions regarding the below, please <a href="contact.php">Contact Us</a> immediately.</p>

<p>[Mahara] will occasionally be unavailable for short periods of time as we release new system features.  We will endeavour to provide at least 3 working days notice of any scheduled outage.</p>

<p>You are encouraged to report objectionable material or inappropriate behaviour to the <a href="contact.php">Site Administrator</a> immediately.  We will ensure the matter is investigated in a timely manner.</p>

<p>Site Administrators may access your portfolio and its contents at anytime, however they will avoid doing so unless specifically required to support your use of [Mahara] or as per these Terms and Conditions.</p>

<h2>Your obligations</h2>

<p> The <a href="privacy.php">Privacy Statement</a> should be considered an extension of these Terms and Conditions and be read by all users.</p>

<p>Your [Mahara] account will expire after a given period of time or after given period of inactivity, as set by the Site Administrator. You will receive an email reminder shortly before your account is due to expire and we suggest you save your portfolio to your personal computer at this time, so that you may reuse it in the future.</p>

<p>All files and content you upload to [Mahara] are subject to New Zealand Copyright legislation.  You are responsible for ensuring you have appropriate permission to reproduce and publish any work that is not your own.  Incidents of plagiarism will be dealt with in accordance to your educational institution\'s policy.</p>

<p>You must not use your portfolio to store or display offensive material.  If the Site Administrator receives report of any objectionable material within your portfolio, your account will be suspended and your access to [Mahara] frozen pending an investigation in accordance to the Student Conduct Policy or equivalent of your educational institution.  Where no Conduct Policy exists the matter will be referred to an appropriate staff member of your institution or organisation.</p>

<p>If the Site Administrator receives report of any inappropriate behaviour on your part, where it relates to [Mahara], your account will be suspended and your access to [Mahara] frozen pending an investigation in accordance to the Student Conduct Policy or equivalent of your educational institution.  Where no Conduct Policy exists the matter will be referred to an appropriate staff member of your institution or organisation.</p>

<p>Inappropriate behaviour includes misuse of the objectionable material reporting system, intentionally attempting to load files with virus content, placing objectionable or excessive feedback or comments on any other users portfolio and any other behaviour deemed to be nuisance or offensive by the Site Administrator.</p>

<p>Any unsolicited contact you receive as a result of personal information you have publicly released via your portfolio is your responsibility, however any misconduct in behaviour from users of the system should be reported to the <a href="contact.php">Site Administrator</a> immediately.  We may occasionally make minor adjustments to our Terms and Condition to reflect changes to the system and in response to user feedback.  As such we suggest you check the Terms and Conditions each time you visit this site.  We will however notify users of any major changes to the Terms and Conditions via the [Mahara] homepage.</p>';

$string['uploadcopyrightdefaultcontent'] = 'Yes: The file I am attempting to upload is my own or I have express permission to reproduce and/or distribute this item.  My use of this file does not breach any of my local Copyright legislation. This file also adheres to the Terms and Conditions outlined on this site.';

?>
